config = {
    "attention_probs_dropout_prob": 0.1,
    "hidden_act": "gelu",
    "intermediate_act": "relu",
    "hidden_dropout_prob": 0.1,
    "embedding_size": 512,
    "initializer_range": 0.02,
    "intermediate_size": 2048,
    "max_position_embeddings": -1,
    "num_attention_heads": 8,
    "attention_head_size": 64,
    "num_hidden_layers": 6,
    "vocab_size": 32128,
    "type_vocab_size": -1,
    "layer_norm_epsilon": 1e-06,
    "bidirectional": True,
    "positional_buckets": 32,
}
